Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(28)

Unified Diff: compiler/java/com/google/dart/compiler/UnitTestBatchRunner.java

Issue 8231031: Check for compile-time constants in DartCompiler (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Feedback from floitsch Created 9 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: compiler/java/com/google/dart/compiler/UnitTestBatchRunner.java
diff --git a/compiler/java/com/google/dart/compiler/UnitTestBatchRunner.java b/compiler/java/com/google/dart/compiler/UnitTestBatchRunner.java
index e8225f41715ae04924d71b76616cf950cfc36c6b..790d10833e782af7b7c7ae4ee17de6682d020daf 100644
--- a/compiler/java/com/google/dart/compiler/UnitTestBatchRunner.java
+++ b/compiler/java/com/google/dart/compiler/UnitTestBatchRunner.java
@@ -4,12 +4,15 @@
package com.google.dart.compiler;
+
+import com.google.dart.runner.DartRunner;
+
import java.io.BufferedReader;
import java.io.InputStreamReader;
/**
* Provides a framework to read command line options from stdin and feed them to
* either the DartCompiler or TestRunner.
*
*/
public class UnitTestBatchRunner {
@@ -4,12 +4,15 @@
/**
* Provides a framework to read command line options from stdin and feed them to
- * either the DartCompiler or TestRunner.
+ * either the {@link DartCompiler} or {@link DartRunner}.
*
*/

Powered by Google App Engine
This is Rietveld 408576698